Create a new ufmgthesis Quarto project from the package template
Source:R/create_ufmgthesis.R
create_template.RdCreate a new ufmgthesis Quarto project from the package template
R/create_ufmgthesis.R
create_template.RdCreate a new ufmgthesis Quarto project from the package template